MetadataError

Enum MetadataError 

#[non_exhaustive]
pub enum MetadataError {
Show 14 variants ValueAccess { key: String, source: Box<ValueError>, }, MissingKey(String), TypeMismatch { key: String, expected: DataType, actual: DataType, message: String, }, WireLimitExceeded { kind: MetadataWireLimitKind, value: usize, maximum: usize, }, MissingRequiredField { key: String, expected: DataType, }, UnknownField { key: String, }, UnknownFilterField { key: String, }, InvalidFilterOperator { key: String, operator: &'static str, data_type: DataType, message: String, }, InvalidFilterExpression { message: String, }, InvalidFilterOperand { operator: &'static str, data_type: DataType, message: String, }, MissingFilterExpression, InvalidFilterLimit { kind: FilterLimitKind, value: usize, maximum: usize, }, FilterLimitExceeded { kind: FilterLimitKind, value: usize, maximum: usize, }, DuplicateSchemaField { key: String, },
}
Errors produced by explicit metadata accessors and schema validation.

Examples

use qubit_metadata::MetadataError;

let error = MetadataError::MissingKey("tenant".to_owned());
assert!(error.to_string().contains("tenant"));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ValueAccess

A strict read or explicit conversion failed without losing its source.

Fields

key: String

Metadata key being read.

source: Box<ValueError>

Original structured value error.



MissingKey(String)

The requested key does not exist.

Tuple Fields

0: String

Missing metadata key.



TypeMismatch

Schema validation found a stored value of the wrong type.

Fields

key: String

Metadata key being read or validated.

expected: DataType

Expected data type.

actual: DataType

Actual stored data type.

message: String

Human-readable conversion or validation message.



WireLimitExceeded

A metadata or schema value exceeds a strict V1 wire limit.

Fields

kind: MetadataWireLimitKind

Wire resource category that exceeded its limit.

value: usize

Observed resource value.

maximum: usize

Largest value accepted by the V1 wire contract.



MissingRequiredField

A required schema field is missing from a metadata object.

Fields

key: String

Required metadata key.

expected: DataType

Expected data type for the missing field.



UnknownField

A metadata object contains a key not accepted by the schema.

Fields

key: String

Unknown metadata key.



UnknownFilterField

A filter references a key that is not defined by the schema.

Fields

key: String

Unknown filter key.



InvalidFilterOperator

A filter uses an operator that is not compatible with the field type.

Fields

key: String

Metadata key being filtered.

operator: &'static str

Filter operator name.

data_type: DataType

Field data type defined by the schema.

message: String

Human-readable validation message.



InvalidFilterExpression

A filter expression is structurally invalid.

Fields

message: String

Human-readable validation message.



InvalidFilterOperand

A filter condition uses an operand with no stable matching semantics.

Fields

operator: &'static str

Stable filter operator name.

data_type: DataType

Data type declared by the rejected operand.

message: String

Human-readable rejection reason.



MissingFilterExpression

A metadata-filter builder was finalized without an expression.



InvalidFilterLimit

A configured filter resource bound is outside the allowed range.

Fields

kind: FilterLimitKind

Resource category being configured.

value: usize

Requested resource bound.

maximum: usize

Library hard maximum for the resource.



FilterLimitExceeded

A filter exceeds an enforced resource bound.

Fields

kind: FilterLimitKind

Resource category that exceeded its limit.

value: usize

Observed resource value.

maximum: usize

Largest allowed value for the resource.



DuplicateSchemaField

A schema builder declares the same field more than once.

Fields

key: String

Duplicated schema key.