UnknownFieldPolicy

Enum UnknownFieldPolicy 

pub enum UnknownFieldPolicy {
    Reject,
    Allow,
}
Policy for fields that appear in metadata or filters but are not declared by a schema.

Variants



Reject

Reject fields that are not declared in the schema.



Allow

Allow fields that are not declared in the schema.