pub enum UnknownMetadataFieldPolicy {
Reject,
Allow,
}Expand description
Policy for metadata fields that are not declared by a schema.
Examples
use qubit_metadata::UnknownMetadataFieldPolicy;
assert_eq!(UnknownMetadataFieldPolicy::default(), UnknownMetadataFieldPolicy::Reject);Variants
Reject
Reject metadata keys that are not declared in the schema.
Allow
Allow metadata keys that are not declared in the schema.