MetadataSchemaBuilder

Struct MetadataSchemaBuilder 

pub struct MetadataSchemaBuilder { /* private fields */ }
Builder for MetadataSchema.

Examples

use qubit_datatype::DataType;
use qubit_metadata::MetadataSchema;

let schema = MetadataSchema::builder()
    .required("tenant", DataType::String)
    .build()?;
assert!(schema.field("tenant").is_some());

Implementations

Source

impl MetadataSchemaBuilder

pub fn required(self, key: &str, data_type: DataType) -> Self

Adds a required field definition.

Parameters
  • key - Metadata key to declare.
  • data_type - Concrete data type accepted by the field.
Returns

The updated builder.

pub fn optional(self, key: &str, data_type: DataType) -> Self

Adds an optional field definition.

Parameters
  • key - Metadata key to declare.
  • data_type - Concrete data type accepted by the field.
Returns

The updated builder.

pub fn replace_field(self, key: &str, field: MetadataField) -> Self

Explicitly replaces a field definition.

Parameters
  • key - Metadata key to replace.
  • field - Replacement definition.
Returns

The updated builder. This is the only declaration method that may overwrite an existing field.

pub fn unknown_metadata_field_policy( self, policy: UnknownMetadataFieldPolicy, ) -> Self

Sets the policy for metadata keys not declared by the schema.

Parameters
  • policy - Unknown metadata-field policy to store.
Returns

The updated builder.

pub fn unknown_filter_field_policy( self, policy: UnknownFilterFieldPolicy, ) -> Self

Sets the policy for filter keys not declared by the schema.

Parameters
  • policy - Unknown filter-field policy to store.
Returns

The updated builder.

pub fn build(self) -> MetadataResult<MetadataSchema>

Builds the schema.

Returns

The immutable schema described by this builder.

Errors

Returns MetadataError::DuplicateSchemaField when required or optional declare the same key more than once.